# JSON Schemas

<div class="grid cards" markdown>
- [:material-code-json:{ .lg .middle } TypeScript Types](https://www.npmjs.com/package/@cattle-grid/muck-out-types)

    ---

    Generated NPM package to import the types
</div>

## Download

- [Activity](./schemas/activity.json)
- [Actor](./schemas/actor.json)
- [Collection](./schemas/collection.json)
- [Object](./schemas/object.json)
- [ActorHeaderInfo](./schemas/actor-header-info.json)
- [ObjectMetaInfo](./schemas/object-meta-info.json)

## Activity

```json
--8<-- "./docs/schemas/activity.json"
```

## Actor

```json
--8<-- "./docs/schemas/actor.json"
```

## Collection

```json
--8<-- "./docs/schemas/collection.json"
```

## Object

```json
--8<-- "./docs/schemas/object.json"
```